==> kmail-22.11.90.tar.xz: kmail-22.11.90/src/kontactplugin/summary/summaryplugin.json.cmake <==
{
    "KPlugin": {
        "Description": "Kontact SummaryView Plugin",
        "Description[ar]": "ملحقة «منظور الملخّصات» لِ‍«متراسلك»",
        "Description[az]": "Kontact yekununa baxış plaqini",
        "Description[bg]": "Приставка за обобщен преглед на контакти",
        "Description[ca@valencia]": "Connector de la vista de resum de Kontact",
        "Description[ca]": "Connector de la vista de resum del Kontact",
        "Description[cs]": "Modul souhrnu pro aplikaci Kontact",
        "Description[de]": "Übersichts-Modul für Kontact",
        "Description[en_GB]": "Kontact SummaryView Plugin",
        "Description[es]": "Complemento de vista de resumen para Kontact",
        "Description[eu]": "Kontact-eko laburpen ikuspegirako plugina",
        "Description[fi]": "Kontactin yhteenvetonäkymäliitännäinen",
        "Description[fr]": "Module externe « Affichage de résumés » pour Kontact",
        "Description[ia]": "Plug-in pro Kontact SummaryView",
        "Description[id]": "Plugin Kontact SummaryView",
        "Description[it]": "Estensione vista sommario per Kontact",
        "Description[ko]": "Kontact 요약 보기 플러그인",
        "Description[nl]": "Kontact SummaryView-plug-in",
        "Description[pl]": "Wtyczka Kontact do wyświetlania podsumowania",
        "Description[pt]": "'Plugin' do SummaryView do Kontact",
        "Description[pt_BR]": "Plugin de Visualização do resumo do Kontact",
        "Description[ru]": "Просмотр дайджеста",
        "Description[sl]": "Vstavek pogleda povzetkov za Kontact",
        "Description[sv]": "Kontact-insticksprogram för översikt",
        "Description[ta]": "காண்டாக்டுக்கான சுருக்கக்காட்சி செருகுநிரல்",
        "Description[tr]": "Kontact Özet Gösterim Eklentisi",
        "Description[uk]": "Додаток Kontact для перегляду резюме",
        "Description[x-test]": "xxKontact SummaryView Pluginxx",
        "Description[zh_CN]": "Kontact 摘要视图插件",
        "EnabledByDefault": true,
        "Icon": "view-calendar-agenda",
        "Id": "kontact_summaryplugin",
        "InitialPreference": 0,
        "License": "LGPL",
        "Name": "Summary",
        "Name[af]": "Opsomming",
        "Name[ar]": "الملخّص",
        "Name[az]": "Xülasə",
        "Name[bg]": "Обобщение",
        "Name[br]": "Diverrañ",
        "Name[bs]": "Rezime",
        "Name[ca@valencia]": "Resum",
        "Name[ca]": "Resum",
        "Name[cs]": "Souhrn",
        "Name[cy]": "Crynodeb",
        "Name[da]": "Oversigt",
        "Name[de]": "Übersicht",
        "Name[el]": "Σύνοψη",
        "Name[en_GB]": "Summary",
        "Name[eo]": "Resumo",
        "Name[es]": "Resumen",
        "Name[et]": "Kokkuvõte",
        "Name[eu]": "Laburpena",
        "Name[fa]": "خلاصه",
        "Name[fi]": "Yhteenveto",
        "Name[fr]": "Résumé",
        "Name[fy]": "Oersicht",
        "Name[ga]": "Achoimre",
        "Name[gl]": "Resumo",
        "Name[he]": "תקציר",
        "Name[hu]": "Áttekintő",
        "Name[ia]": "Summario",
        "Name[id]": "Ringkasan",
        "Name[is]": "Yfirlit",
        "Name[it]": "Sommario",
        "Name[ja]": "要約",
        "Name[ka]": "შეჯამება",
        "Name[kk]": "Мазмұндама",
        "Name[km]": "សង្ខេប",
        "Name[ko]": "요약",
        "Name[ku]": "Kurte",
        "Name[lt]": "Santrauka",
        "Name[lv]": "Kopsavilkums",
        "Name[mai]": "सारांश",
        "Name[mk]": "Преглед",
        "Name[mr]": "सारांश",
        "Name[ms]": "Ringkasan",
        "Name[nb]": "Sammendrag",
        "Name[nds]": "Översicht",
        "Name[ne]": "सारांश",
        "Name[nl]": "Overzicht",
        "Name[nn]": "Samandrag",
        "Name[pa]": "ਸੰਖੇਪ",
        "Name[pl]": "Podsumowanie",
        "Name[pt]": "Resumo",
        "Name[pt_BR]": "Resumo",
        "Name[ro]": "Sumar",
        "Name[ru]": "Дайджест",
        "Name[se]": "Čoahkkáigeassu",
        "Name[sk]": "Súhrn",
        "Name[sl]": "Povzetek",
        "Name[sr@ijekavian]": "Сажетак",
        "Name[sr@ijekavianlatin]": "Sažetak",
        "Name[sr@latin]": "Sažetak",
        "Name[sr]": "Сажетак",
        "Name[sv]": "Översikt",
        "Name[ta]": "சுருக்கம்",
        "Name[tg]": "Дайджест",
        "Name[th]": "รายงานสรุป",
        "Name[tr]": "Özet",
        "Name[ug]": "ئۈزۈندى",
        "Name[uk]": "Резюме",
        "Name[uz@cyrillic]": "Ҳисобот",
        "Name[uz]": "Hisobot",
        "Name[wa]": "Racourti",
        "Name[x-test]": "xxSummaryxx",
        "Name[zh_CN]": "总计",
        "Name[zh_TW]": "摘要",
        "Version": "0.1"
    },
    "X-KDE-ConfigModuleNamespace": "pim@QT_MAJOR_VERSION@/kcms/summary/",
    "X-KDE-KontactPluginVersion": 11,
    "X-KDE-Weight": "100"
}

==> kmail-23.04.2.tar.xz: kmail-23.04.2/src/kontactplugin/summary/summaryplugin.json.cmake <==
{
    "KPlugin": {
        "Description": "Kontact SummaryView Plugin",
        "Description[ar]": "ملحقة «منظور الملخّصات» لِ‍«متراسلك»",
        "Description[az]": "Kontact yekununa baxış plaqini",
        "Description[bg]": "Приставка за обобщен преглед на контакти",
        "Description[ca@valencia]": "Connector de la vista de resum de Kontact",
        "Description[ca]": "Connector de la vista de resum del Kontact",
        "Description[cs]": "Modul souhrnu pro aplikaci Kontact",
        "Description[de]": "Übersichts-Modul für Kontact",
        "Description[en_GB]": "Kontact SummaryView Plugin",
        "Description[eo]": "Kontact ResumRigardo-Kromprogramo",
        "Description[es]": "Complemento de vista de resumen para Kontact",
        "Description[eu]": "Kontact-eko laburpen ikuspegirako plugina",
        "Description[fi]": "Kontactin yhteenvetonäkymäliitännäinen",
        "Description[fr]": "Module externe « Affichage de résumés » pour Kontact",
        "Description[ia]": "Plug-in pro Kontact SummaryView",
        "Description[id]": "Plugin Kontact SummaryView",
        "Description[it]": "Estensione vista sommario per Kontact",
        "Description[ko]": "Kontact 요약 보기 플러그인",
        "Description[nl]": "Kontact SummaryView-plug-in",
        "Description[pl]": "Wtyczka Kontact do wyświetlania podsumowania",
        "Description[pt]": "'Plugin' do SummaryView do Kontact",
        "Description[pt_BR]": "Plugin de Visualização do resumo do Kontact",
        "Description[ru]": "Просмотр дайджеста",
        "Description[sl]": "Vstavek pogleda povzetkov za Kontact",
        "Description[sv]": "Kontact-insticksprogram för översikt",
        "Description[ta]": "காண்டாக்டுக்கான சுருக்கக்காட்சி செருகுநிரல்",
        "Description[tr]": "Kontak Özet Gösterim Eklentisi",
        "Description[uk]": "Додаток Kontact для перегляду резюме",
        "Description[x-test]": "xxKontact SummaryView Pluginxx",
        "Description[zh_CN]": "Kontact 摘要视图插件",
        "EnabledByDefault": true,
        "Icon": "view-calendar-agenda",
        "Id": "kontact_summaryplugin",
        "InitialPreference": 0,
        "License": "LGPL",
        "Name": "Summary",
        "Name[af]": "Opsomming",
        "Name[ar]": "الملخّص",
        "Name[az]": "Xülasə",
        "Name[bg]": "Обобщение",
        "Name[br]": "Diverrañ",
        "Name[bs]": "Rezime",
        "Name[ca@valencia]": "Resum",
        "Name[ca]": "Resum",
        "Name[cs]": "Souhrn",
        "Name[cy]": "Crynodeb",
        "Name[da]": "Oversigt",
        "Name[de]": "Übersicht",
        "Name[el]": "Σύνοψη",
        "Name[en_GB]": "Summary",
        "Name[eo]": "Resumo",
        "Name[es]": "Resumen",
        "Name[et]": "Kokkuvõte",
        "Name[eu]": "Laburpena",
        "Name[fa]": "خلاصه",
        "Name[fi]": "Yhteenveto",
        "Name[fr]": "Résumé",
        "Name[fy]": "Oersicht",
        "Name[ga]": "Achoimre",
        "Name[gl]": "Resumo",
        "Name[he]": "תקציר",
        "Name[hu]": "Áttekintő",
        "Name[ia]": "Summario",
        "Name[id]": "Ringkasan",
        "Name[is]": "Yfirlit",
        "Name[it]": "Sommario",
        "Name[ja]": "要約",
        "Name[ka]": "შეჯამება",
        "Name[kk]": "Мазмұндама",
        "Name[km]": "សង្ខេប",
        "Name[ko]": "요약",
        "Name[ku]": "Kurte",
        "Name[lt]": "Santrauka",
        "Name[lv]": "Kopsavilkums",
        "Name[mai]": "सारांश",
        "Name[mk]": "Преглед",
        "Name[mr]": "सारांश",
        "Name[ms]": "Ringkasan",
        "Name[nb]": "Sammendrag",
        "Name[nds]": "Översicht",
        "Name[ne]": "सारांश",
        "Name[nl]": "Overzicht",
        "Name[nn]": "Samandrag",
        "Name[pa]": "ਸੰਖੇਪ",
        "Name[pl]": "Podsumowanie",
        "Name[pt]": "Resumo",
        "Name[pt_BR]": "Resumo",
        "Name[ro]": "Sumar",
        "Name[ru]": "Дайджест",
        "Name[se]": "Čoahkkáigeassu",
        "Name[sk]": "Súhrn",
        "Name[sl]": "Povzetek",
        "Name[sr@ijekavian]": "Сажетак",
        "Name[sr@ijekavianlatin]": "Sažetak",
        "Name[sr@latin]": "Sažetak",
        "Name[sr]": "Сажетак",
        "Name[sv]": "Översikt",
        "Name[ta]": "சுருக்கம்",
        "Name[tg]": "Дайджест",
        "Name[th]": "รายงานสรุป",
        "Name[tr]": "Özet",
        "Name[ug]": "ئۈزۈندى",
        "Name[uk]": "Резюме",
        "Name[uz@cyrillic]": "Ҳисобот",
        "Name[uz]": "Hisobot",
        "Name[wa]": "Racourti",
        "Name[x-test]": "xxSummaryxx",
        "Name[zh_CN]": "总计",
        "Name[zh_TW]": "摘要",
        "Version": "0.1"
    },
    "X-KDE-ConfigModuleNamespace": "pim@QT_MAJOR_VERSION@/kcms/summary/",
    "X-KDE-KontactPluginVersion": 11,
    "X-KDE-Weight": "100"
}
